==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/outputs/GoogleCloudStorageLocationResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.outputs

import kotlin.Any
import kotlin.String
import kotlin.Suppress

/**
 * The location of Google Cloud Storage dataset.
 * @property bucketName Specify the bucketName of Google Cloud Storage. Type: string (or Expression with resultType string)
 * @property fileName Specify the file name of dataset. Type: string (or Expression with resultType string).
 * @property folderPath Specify the folder path of dataset. Type: string (or Expression with resultType string)
 * @property type Type of dataset storage location.
 * Expected value is 'GoogleCloudStorageLocation'.
 * @property version Specify the version of Google Cloud Storage. Type: string (or Expression with resultType string).
 */
public data class GoogleCloudStorageLocationResponse(
    public val bucketName: Any? = null,
    public val fileName: Any? = null,
    public val folderPath: Any? = null,
    public val type: String,
    public val version: Any? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.datafactory.outputs.GoogleCloudStorageLocationResponse):
            GoogleCloudStorageLocationResponse = GoogleCloudStorageLocationResponse(
            bucketName = javaType.bucketName().map({ args0 -> args0 }).orElse(null),
            fileName = javaType.fileName().map({ args0 -> args0 }).orElse(null),
            folderPath = javaType.folderPath().map({ args0 -> args0 }).orElse(null),
            type = javaType.type(),
            version = javaType.version().map({ args0 -> args0 }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/outputs/GoogleCloudStorageLocationResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.outputs

import kotlin.Any
import kotlin.String
import kotlin.Suppress

/**
 * The location of Google Cloud Storage dataset.
 * @property bucketName Specify the bucketName of Google Cloud Storage. Type: string (or Expression with resultType string)
 * @property fileName Specify the file name of dataset. Type: string (or Expression with resultType string).
 * @property folderPath Specify the folder path of dataset. Type: string (or Expression with resultType string)
 * @property type Type of dataset storage location.
 * Expected value is 'GoogleCloudStorageLocation'.
 * @property version Specify the version of Google Cloud Storage. Type: string (or Expression with resultType string).
 */
public data class GoogleCloudStorageLocationResponse(
    public val bucketName: Any? = null,
    public val fileName: Any? = null,
    public val folderPath: Any? = null,
    public val type: String,
    public val version: Any? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.datafactory.outputs.GoogleCloudStorageLocationResponse): GoogleCloudStorageLocationResponse = GoogleCloudStorageLocationResponse(
            bucketName = javaType.bucketName().map({ args0 -> args0 }).orElse(null),
            fileName = javaType.fileName().map({ args0 -> args0 }).orElse(null),
            folderPath = javaType.folderPath().map({ args0 -> args0 }).orElse(null),
            type = javaType.type(),
            version = javaType.version().map({ args0 -> args0 }).orElse(null),
        )
    }
}
